#
# spec file for package perl-HTTP-Cookies
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name HTTP-Cookies
Name:           perl-HTTP-Cookies
Version:        6.110.0
Release:        2.1
%define cpan_version 6.11
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        HTTP cookie jars
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/O/OA/OALDERS/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(HTTP::Date) >= 6
BuildRequires:  perl(HTTP::Headers::Util) >= 6
BuildRequires:  perl(HTTP::Request)
BuildRequires:  perl(HTTP::Response)
BuildRequires:  perl(URI)
Requires:       perl(HTTP::Date) >= 6
Requires:       perl(HTTP::Headers::Util) >= 6
Requires:       perl(HTTP::Request)
Provides:       perl(HTTP::Cookies) = %{version}
Provides:       perl(HTTP::Cookies::Microsoft) = %{version}
Provides:       perl(HTTP::Cookies::Netscape) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
This class is for objects that represent a "cookie jar" -- that is, a
database of all the HTTP cookies that a given LWP::UserAgent object knows
about.

Cookies are a general mechanism which server side connections can use to
both store and retrieve information on the client side of the connection.
For more information about cookies refer to at
http://curl.haxx.se/rfc/cookie_spec.html and at
http://www.cookiecentral.com. This module also implements the new style
cookies described in at https://tools.ietf.org/html/rfc2965. The two
variants of cookies are supposed to be able to coexist happily.

Instances of the class _HTTP::Cookies_ are able to store a collection of
Set-Cookie2: and Set-Cookie: headers and are able to use this information
to initialize Cookie-headers in _HTTP::Request_ objects. The state of a
_HTTP::Cookies_ object can be saved in and restored from files.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes CONTRIBUTORS README.md
%license LICENSE

%changelog
* Fri Mar  8 2024 Tina Müller <tina.mueller@suse.com>
- Fix disabling of __perllib_provides
* Fri Dec  8 2023 Tina Müller <timueller+perl@suse.de>
- updated to 6.11
  see /usr/share/doc/packages/perl-HTTP-Cookies/Changes
  6.11      2023-12-07 16:36:52Z
  - Replace "Test" with "Test::More" (GH#70) (James Raspass)
* Tue Jan  5 2021 Tina Müller <timueller+perl@suse.de>
- updated to 6.10
  see /usr/share/doc/packages/perl-HTTP-Cookies/Changes
  6.10      2021-01-04 22:03:43Z
  - Do not set discard if max-age is set (GH#61) (robnagler, simbabque)
  - Add tests for #61 - do not set discard if max-age is set (GH#65) (Julien Fiegehenn)
* Fri Nov 20 2020 Tina Müller <timueller+perl@suse.de>
- updated to 6.09
  see /usr/share/doc/packages/perl-HTTP-Cookies/Changes
  6.09      2020-11-19 22:20:47Z
  - Allow HttpOnly cookies to be loaded by HTTP::Cookies::Netscape (GH#63)
    (Charlie Hothersall-Thomas)
* Tue Dec  3 2019 <timueller+perl@suse.de>
- updated to 6.08
  see /usr/share/doc/packages/perl-HTTP-Cookies/Changes
  6.08      2019-12-02 15:58:32Z
  - allow different "ignore_discard" value at save() time (GH#2) (Alex Peters)
* Tue Nov 19 2019 <timueller+perl@suse.de>
- updated to 6.07
  see /usr/share/doc/packages/perl-HTTP-Cookies/Changes
  6.07      2019-11-15 18:11:42Z
  - Fix t/issue32.t on old perl versions (GH#59) (Bernhard M. Wiedemann)
* Thu Nov 14 2019 <timueller+perl@suse.de>
- updated to 6.06
  see /usr/share/doc/packages/perl-HTTP-Cookies/Changes
  6.06      2019-11-12 14:28:31Z
  - Make test pass in 2025 (GH#56) (Bernhard M. Wiedemann)
* Fri Oct 25 2019 <timueller+perl@suse.de>
- updated to 6.05
  see /usr/share/doc/packages/perl-HTTP-Cookies/Changes
  6.05      2019-10-24 02:21:51Z
  - Fix GH#32 by checking for " as well as ; when splitting. (GH#49) (colinnewell)
  - Fix GH#48 update documentation about $version (GH#55) (Dave Menninger)
  - Fix broken README badge (GH#54) (Alex Peters)
  - Whenever possible, use an absolute four digit year for Time::Local (GH#52) (Olaf Alders)
  - Add test case for Issue #26 (GH#45) (George-NG)
  - Long numbers (GH#47) (pludlamCVL)
  - Cookies.pm: die if close on $fh in ->save fails (GH#46) (MCRayRay)
  - Replace "use vars" with "our" (GH#43) (James Raspass)
  - Fixed minor typo in the pod for HTTP::Cookies. (GH#39) (Mohammad S Anwar)
* Fri Aug  4 2017 coolo@suse.com
- updated to 6.04
  see /usr/share/doc/packages/perl-HTTP-Cookies/Changes
  6.04      2017-08-03 15:05:22Z
  - Fix package version numbers
* Tue Apr  4 2017 coolo@suse.com
- updated to 6.03
  see /usr/share/doc/packages/perl-HTTP-Cookies/Changes
* Thu Feb 16 2012 coolo@suse.com
- updated to 6.01
  * Restore 5.8.1 compatiblity.
* Mon Mar 14 2011 vcizek@novell.com
- initial package 6.00
  * created by cpanspec 1.78.03
